@@ -1,3 +1,3 @@
 if __name__ == "__main__":
-    from faker.cli import execute_from_command_line
+    from .cli import execute_from_command_line
     execute_from_command_line()
