@@ -1147,22 +1147,22 @@ class Provider(AddressProvider):
         'Socialistická federatívna republika Juhoslávia', 'Zairská republika',
     )
 
-    def street_suffix_short(self):
+    def street_suffix_short(self) -> str:
         return self.random_element(self.street_suffixes_short)
 
-    def street_suffix_long(self):
+    def street_suffix_long(self) -> str:
         return self.random_element(self.street_suffixes_long)
 
-    def city_name(self):
+    def city_name(self) -> str:
         return self.random_element(self.cities)
 
-    def street_name(self):
+    def street_name(self) -> str:
         return self.random_element(self.streets)
 
-    def administrative_unit(self):
+    def administrative_unit(self) -> str:
         return self.random_element(self.states)
 
     state = administrative_unit
 
-    def city_with_postcode(self):
+    def city_with_postcode(self) -> str:
         return self.postcode() + " " + self.random_element(self.cities)
