@@ -2055,26 +2055,26 @@ class Provider(AddressProvider):
         'Яші Гордієнка',
     ]
 
-    def city_prefix(self):
+    def city_prefix(self) -> str:
         return self.random_element(self.city_prefixes)
 
-    def city_name(self):
+    def city_name(self) -> str:
         return self.random_element(self.city_names)
 
-    def postcode(self):
+    def postcode(self) -> str:
         """The code consists of five digits (01000-99999)"""
         return f'{self.generator.random.randint(0, 10)}{self.generator.random.randint(1000, 10000)}'
 
-    def street_prefix(self):
+    def street_prefix(self) -> str:
         return self.random_element(self.street_prefixes)
 
-    def street_name(self):
+    def street_name(self) -> str:
         return self.random_element(self.street_titles)
 
-    def street_title(self):
+    def street_title(self) -> str:
         prefix = self.street_prefix()
         street = self.street_name()
         return prefix + ' ' + street
 
-    def region(self):
+    def region(self) -> str:
         return self.random_element(self.region_names)
