@@ -5,5 +5,5 @@ class Provider(CurrencyProvider):
 
     price_formats = ["#.##", "%#.##", "%##.##", "%,###.##", "%#,###.##"]
 
-    def pricetag(self):
+    def pricetag(self) -> str:
         return ("$" + self.numerify(self.random_element(self.price_formats)))
