@@ -1,12 +1,9 @@
-# coding: utf-8
-from __future__ import unicode_literals
-
 from .. import Provider as DateTimeProvider
 
 
 class Provider(DateTimeProvider):
 
-    def day_of_week(self):
+    def day_of_week(self) -> str:
         day = self.date('%w')
         DAY_NAMES = {
             "0": "일요일",
@@ -19,7 +16,7 @@ class Provider(DateTimeProvider):
         }
         return DAY_NAMES[day]
 
-    def month_name(self):
+    def month_name(self) -> str:
         month = self.month()
         MONTH_NAMES = {
             "01": "1월",
