@@ -1,4 +1,3 @@
-# coding=utf-8
 """
 This module exists solely to figure how long a registrant/publication
 number may be within an ISBN. The rules change based on the prefix and
@@ -11,12 +10,13 @@ https://www.isbn-international.org/range_file_generation
 """
 
 from collections import namedtuple
+from typing import Dict, List
 
 RegistrantRule = namedtuple(
     'RegistrantRule', ['min', 'max', 'registrant_length'])
 
 # Structure: RULES[`EAN Prefix`][`Registration Group`] = [Rule1, Rule2, ...]
-RULES = {
+RULES: Dict[str, Dict[str, List[RegistrantRule]]] = {
     '978': {
         '0': [
             RegistrantRule('0000000', '1999999', 2),
