@@ -1,18 +1,19 @@
 from collections import OrderedDict
+from typing import Dict, Sequence
 
 from .. import Provider as PersonProvider
 
 
 # See transliteration table https://en.wikipedia.org/wiki/Romanization_of_Russian#Transliteration_table
-def translit(text):
-    translit_dict = {
-      'а': 'a', 'б': 'b', 'в': 'v', 'г': 'g', 'д': 'd', 'е': 'e', 'ё': 'e', 'ж': 'zh', 'з': 'z', 'и': 'i', 'й': 'y',
-      'к': 'k', 'л': 'l', 'м': 'm', 'н': 'n', 'о': 'o', 'п': 'p', 'р': 'r', 'с': 's', 'т': 't', 'у': 'u', 'ф': 'f',
-      'х': 'kh', 'ц': 'ts', 'ч': 'ch', 'ш': 'sh', 'щ': 'shch', 'ъ': '', 'ы': 'y', 'ь': '', 'э': 'e', 'ю': 'yu',
-      'я': 'ya', 'А': 'A', 'Б': 'B', 'В': 'V', 'Г': 'G', 'Д': 'D', 'Е': 'Ye', 'Ë': 'E', 'Ж': 'Zh', 'З': 'Z', 'И': 'I',
-      'Й': 'Y', 'К': 'K', 'Л': 'L', 'М': 'M', 'Н': 'N', 'О': 'O', 'П': 'P', 'Р': 'R', 'С': 'S', 'Т': 'T', 'У': 'U',
-      'Ф': 'F', 'Х': 'Kh', 'Ц': 'Ts', 'Ч': 'Ch', 'Ш': 'Sh', 'Щ': 'Shch', 'Ы': 'Y', 'Э': 'E', 'Ю': 'Yu', 'Я': 'Ya',
-     }
+def translit(text: str) -> str:
+    translit_dict: Dict[str, str] = {
+        'а': 'a', 'б': 'b', 'в': 'v', 'г': 'g', 'д': 'd', 'е': 'e', 'ё': 'e', 'ж': 'zh', 'з': 'z', 'и': 'i', 'й': 'y',
+        'к': 'k', 'л': 'l', 'м': 'm', 'н': 'n', 'о': 'o', 'п': 'p', 'р': 'r', 'с': 's', 'т': 't', 'у': 'u', 'ф': 'f',
+        'х': 'kh', 'ц': 'ts', 'ч': 'ch', 'ш': 'sh', 'щ': 'shch', 'ъ': '', 'ы': 'y', 'ь': '', 'э': 'e', 'ю': 'yu',
+        'я': 'ya', 'А': 'A', 'Б': 'B', 'В': 'V', 'Г': 'G', 'Д': 'D', 'Е': 'Ye', 'Ë': 'E', 'Ж': 'Zh', 'З': 'Z', 'И': 'I',
+        'Й': 'Y', 'К': 'K', 'Л': 'L', 'М': 'M', 'Н': 'N', 'О': 'O', 'П': 'P', 'Р': 'R', 'С': 'S', 'Т': 'T', 'У': 'U',
+        'Ф': 'F', 'Х': 'Kh', 'Ц': 'Ts', 'Ч': 'Ch', 'Ш': 'Sh', 'Щ': 'Shch', 'Ы': 'Y', 'Э': 'E', 'Ю': 'Yu', 'Я': 'Ya',
+    }
     for letter in text:
         if letter.isalpha():
             text = text.replace(letter, translit_dict[letter])
@@ -20,13 +21,13 @@ def translit(text):
 
 
 class Provider(PersonProvider):
-    formats_male = OrderedDict((
+    formats_male: Dict[str, float] = OrderedDict((
         ('{{last_name_male}} {{first_name_male}} {{middle_name_male}}', 0.49),
         ('{{first_name_male}} {{middle_name_male}} {{last_name_male}}', 0.49),
         ('{{prefix_male}} {{last_name_male}} {{first_name_male}} {{middle_name_male}}', 0.02),
     ))
 
-    formats_female = OrderedDict((
+    formats_female: Dict[str, float] = OrderedDict((
         ('{{last_name_female}} {{first_name_female}} {{middle_name_female}}', 0.49),
         ('{{first_name_female}} {{middle_name_female}} {{last_name_female}}', 0.49),
         ('{{prefix_female}} {{last_name_female}} {{first_name_female}} {{middle_name_female}}', 0.02),
@@ -36,7 +37,7 @@ class Provider(PersonProvider):
     #     formats = formats_male + formats_female
     # has to be replaced with something dict and python 2.x compatible
 
-    formats = formats_male.copy()
+    formats: Dict[str, float] = formats_male.copy()
     formats.update(formats_female)
 
     first_names_male = (
@@ -301,15 +302,15 @@ class Provider(PersonProvider):
         'Вьетнамский', 'Идиш', 'Йоруба', 'Китайский', 'Зулу',
     )
 
-    prefixes_male = ('г-н', 'тов.')
+    prefixes_male: Sequence[str] = ('г-н', 'тов.')
 
-    prefixes_female = ('г-жа', 'тов.')
+    prefixes_female: Sequence[str] = ('г-жа', 'тов.')
 
-    def middle_name(self):
+    def middle_name(self) -> str:
         return self.random_element(self.middle_names)
 
-    def middle_name_male(self):
+    def middle_name_male(self) -> str:
         return self.random_element(self.middle_names_male)
 
-    def middle_name_female(self):
+    def middle_name_female(self) -> str:
         return self.random_element(self.middle_names_female)
