@@ -11,7 +11,7 @@ class Provider(BaseProvider):
         'LT############',
     )
 
-    def vat_id(self):
+    def vat_id(self) -> str:
         """
         http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
         :return: a random Lithuanian VAT ID
